=====================
Welcome to civicrmapi
=====================

.. image:: https://img.shields.io/badge/python-3.6%20%7C%203.7%20%7C%203.8%20%7C%203.9%20%7C%203.10%20%7C%203.11-blue
   :target: https://img.shields.io/badge/python-3.6%20%7C%203.7%20%7C%203.8%20%7C%203.9%20%7C%203.10%20%7C%203.11-blue
   :alt: python: 3.6, 3.7, 3.8, 3.9, 3.10, 3.11

.. image:: https://github.com/thomst/civicrmapi/actions/workflows/ci.yml/badge.svg
   :target: https://github.com/thomst/civicrmapi/actions/workflows/ci.yml
   :alt: CI

.. image:: https://coveralls.io/repos/github/thomst/civicrmapi/badge.svg?branch=master
   :target: https://coveralls.io/github/thomst/civicrmapi?branch=master
   :alt: Coveralls


Note
====
This is an early development state. The api is functional, but docs and extensive
tests are not yet available.

Description
===========
Clean and simple bindings to CiviCRM's API. Both APIv3 and APIv4 are supported.


Installation
============
::

   pip install civicrmapi

Usage
=====



Links
=====
* `Repository <https://github.com/thomst/civicrmapi>`_
* `Documentation <https://thomst.github.io/civicrmapi/>`_ (Not yet available!)
